@@ -52,9 +52,8 @@ class CockpitApp(app_module.App):
                                depends=['apache'], is_essential=True,
                                name=_('Cockpit'), icon='fa-wrench',
                                icon_filename='cockpit',
-                               short_description=_('Server Administration'),
                                description=_description, manual_page='Cockpit',
-                               clients=manifest.clients)
+                               clients=manifest.clients, tags=manifest.tags)
         self.add(info)
 
         menu_item = menu.Menu('menu-cockpit', info.name,
