@@ -25,7 +25,7 @@ _description = [
         _('Firewall is a security system that controls the incoming and '
           'outgoing network traffic on your {box_name}. Keeping a '
           'firewall enabled and properly configured reduces risk of '
-          'security threat from the Internet.'), box_name=cfg.box_name)
+          'security threat from the Internet.'), box_name=_(cfg.box_name))
 ]
 
 _port_details: dict[str, list[str]] = {}
@@ -60,7 +60,7 @@ class FirewallApp(app_module.App):
         info = app_module.Info(app_id=self.app_id, version=self._version,
                                is_essential=True, name=_('Firewall'),
                                icon='fa-shield', description=_description,
-                               manual_page='Firewall')
+                               manual_page='Firewall', tags=manifest.tags)
         self.add(info)
 
         menu_item = menu.Menu('menu-firewall', info.name, None, info.icon,
