@@ -24,8 +24,8 @@ _description = [
     format_lazy(
         _('Radicale is a CalDAV and CardDAV server. It allows synchronization '
           'and sharing of scheduling and contact data. To use Radicale, a '
-          '<a href="https://radicale.org/master.html#documentation/supported-'
-          'clients">supported client application</a> is needed. Radicale can '
+          '<a href="https://radicale.org/master.html#supported-clients">'
+          'supported client application</a> is needed. Radicale can '
           'be accessed by any user with a {box_name} login.'),
         box_name=_(cfg.box_name)),
     _('Radicale provides a basic web interface, which only supports creating '
@@ -51,11 +51,9 @@ class RadicaleApp(app_module.App):
 
         info = app_module.Info(app_id=self.app_id, version=self._version,
                                name=_('Radicale'), icon_filename='radicale',
-                               short_description=_('Calendar and Addressbook'),
                                description=_description,
                                manual_page='Radicale',
-                               clients=manifest.clients,
-                               tags=manifest.tags)
+                               clients=manifest.clients, tags=manifest.tags)
         self.add(info)
 
         menu_item = menu.Menu('menu-radicale', info.name,
