@@ -25,10 +25,12 @@ _description = [
           'any user</a> belonging to the feed-reader group.'),
         users_url=reverse_lazy('users:index')),
     format_lazy(
-        _('You can use RSS-Bridge with <a href="{ttrss_url}">Tiny Tiny '
-          'RSS</a> to follow various websites. When adding a feed, enable '
-          'authentication and use your {box_name} credentials.'),
-        ttrss_url=reverse_lazy('ttrss:index'), box_name=cfg.box_name),
+        _('You can use RSS-Bridge with <a href="{miniflux_url}">Miniflux</a> '
+          'or <a href="{ttrss_url}">Tiny Tiny RSS</a> to follow various '
+          'websites. When adding a feed, enable authentication and use your '
+          '{box_name} credentials.'),
+        miniflux_url=reverse_lazy('miniflux:index'),
+        ttrss_url=reverse_lazy('ttrss:index'), box_name=_(cfg.box_name)),
 ]
 
 
@@ -47,7 +49,6 @@ class RSSBridgeApp(app_module.App):
 
         info = app_module.Info(app_id=self.app_id, version=self._version,
                                name=_('RSS-Bridge'), icon_filename='rssbridge',
-                               short_description=_('RSS Feed Generator'),
                                description=_description,
                                manual_page='RSSBridge', donation_url=None,
                                clients=manifest.clients, tags=manifest.tags)
