@@ -51,9 +51,9 @@ class WordPressApp(app_module.App):
 
         info = app_module.Info(
             app_id=self.app_id, version=self._version, name=_('WordPress'),
-            icon_filename='wordpress', short_description=_('Website and Blog'),
-            description=_description, manual_page='WordPress',
-            clients=manifest.clients, tags=manifest.tags,
+            icon_filename='wordpress', description=_description,
+            manual_page='WordPress', clients=manifest.clients,
+            tags=manifest.tags,
             donation_url='https://wordpressfoundation.org/donate/')
         self.add(info)
 
